@@ -86,7 +86,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55900
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55900
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55c00
 #  endif
 #endif
 
@@ -127,6 +127,12 @@
 #else
 #  define KDECLARATIVE_DEPRECATED_VERSION_5_75(text)
 #endif
+
+#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text)
+#endif
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -192,7 +198,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55900
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55c00
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -202,7 +208,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55900
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x55c00
 #  endif
 #endif
 
@@ -233,6 +239,12 @@
 #else
 #  define KDECLARATIVE_DEPRECATED_VERSION_5_75(text)
 #endif
+
+#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text)
+#endif
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
